==> flink-1.11.6-src.tgz: flink-1.11.6/flink-runtime/src/test/java/org/apache/flink/runtime/scheduler/TestExecutionSlotAllocatorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flink.runtime.scheduler;

import org.apache.flink.runtime.jobmanager.slots.TaskManagerGateway;

/** Factory for {@link TestExecutionSlotAllocatorFactory}. */
public class TestExecutionSlotAllocatorFactory implements ExecutionSlotAllocatorFactory {

    private final TestExecutionSlotAllocator testExecutionSlotAllocator;

    public TestExecutionSlotAllocatorFactory() {
        this.testExecutionSlotAllocator = new TestExecutionSlotAllocator();
    }

    public TestExecutionSlotAllocatorFactory(TaskManagerGateway gateway) {
        this.testExecutionSlotAllocator = new TestExecutionSlotAllocator(gateway);
    }

    @Override
    public ExecutionSlotAllocator createInstance(final InputsLocationsRetriever ignored) {
        return testExecutionSlotAllocator;
    }

    public TestExecutionSlotAllocator getTestExecutionSlotAllocator() {
        return testExecutionSlotAllocator;
    }
}

==> flink-1.12.7-src.tgz: flink-1.12.7/flink-runtime/src/test/java/org/apache/flink/runtime/scheduler/TestExecutionSlotAllocatorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.flink.runtime.scheduler;

import org.apache.flink.runtime.jobmanager.slots.TaskManagerGateway;

/** Factory for {@link TestExecutionSlotAllocatorFactory}. */
public class TestExecutionSlotAllocatorFactory implements ExecutionSlotAllocatorFactory {

    private final TestExecutionSlotAllocator testExecutionSlotAllocator;

    public TestExecutionSlotAllocatorFactory() {
        this.testExecutionSlotAllocator = new TestExecutionSlotAllocator();
    }

    public TestExecutionSlotAllocatorFactory(TaskManagerGateway gateway) {
        this.testExecutionSlotAllocator = new TestExecutionSlotAllocator(gateway);
    }

    @Override
    public ExecutionSlotAllocator createInstance(final ExecutionSlotAllocationContext context) {
        return testExecutionSlotAllocator;
    }

    public TestExecutionSlotAllocator getTestExecutionSlotAllocator() {
        return testExecutionSlotAllocator;
    }
}
